library configuration_cards;

/// A Calculator.
import 'package:flutter/material.dart';
import 'package:smooth_page_indicator/smooth_page_indicator.dart';

class ConfigSetting extends StatefulWidget {
  final Function(PageController pageController, bool isLastPage) onTapButton;

  ///for each page , you can set [ConfigurationCard] List.
  /// [ConfigurationCard] ->  title and child for each page
  final List<ConfigurationCard> configurationCardList;

  /// the [lastPageButtonTitle] => If the pageController is on the last page,
  /// the bottom button of the container will take this text.

  final String lastPageButtonTitle;
  final String currentPageButtonTitle;
  const ConfigSetting(
      {super.key,
      required this.onTapButton,
      required this.configurationCardList,
      this.lastPageButtonTitle = 'All Done',
      this.currentPageButtonTitle = 'Continue'});

  @override
  State<ConfigSetting> createState() => _ConfigSettingState();
}

class _ConfigSettingState extends State<ConfigSetting> {
  final PageController pageController = PageController(
    viewportFraction: 1,
  );
  int currentPage = 0;
  bool isLastPage = false;

  @override
  void initState() {
    pageController.addListener(() {
      setState(() {
        currentPage = pageController.page!.toInt().toInt();
      });
      setState(() {
        isLastPage = currentPage == widget.configurationCardList.length - 1;
      });
    });

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final double height = MediaQuery.of(context).size.height;
    
    final ThemeData themeData = Theme.of(context);

    final itemCount = widget.configurationCardList.length;
    return SingleChildScrollView(
      child: Column(children: [
        SizedBox(
          height: height * 0.1,
        ),
        AnimatedSmoothIndicator(
          activeIndex: currentPage,
          count: 2,
          effect: SwapEffect(
              type: SwapType.yRotation, activeDotColor: themeData.primaryColor),
        ),
        SizedBox(
          height: height * 0.02,
        ),
        SizedBox(
          height: height * 0.5,
          child: PageView.builder(
            controller: pageController,
            itemCount: itemCount,
            pageSnapping: true,
            itemBuilder: (context, index) {
              return widget.configurationCardList[index];
            },
          ),
        ),
        setAllConfigButton(
          context,
          themeData,
          currentPage,
          itemCount,
          () {
            widget.onTapButton(pageController, isLastPage);
          },
        )
      ]),
    );
  }

  Padding setAllConfigButton(
    BuildContext context,
    ThemeData themeData,
    int cuttentPage,
    int itemCount,
    Function() onTap,
  ) {
    var borderRadius = BorderRadius.circular(12);
    return Padding(
      padding: const EdgeInsets.all(20.0),
      child: Material(
        borderRadius: borderRadius,
        color: Theme.of(context).primaryColor,
        child: InkWell(
          borderRadius: borderRadius,
          onTap: onTap,
          child: Container(
            // margin: const EdgeInsets.all(24),
            padding: const EdgeInsets.all(8),
            decoration: BoxDecoration(
                color: Colors.transparent, borderRadius: borderRadius),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Text(
                  isLastPage
                      ? widget.lastPageButtonTitle
                      : widget.currentPageButtonTitle,
                  style: themeData.textTheme.subtitle1!
                      .copyWith(color: Colors.white),
                )
              ],
            ),
          ),
        ),
      ),
    );
  }
}

class ConfigurationCard extends StatelessWidget {
  const ConfigurationCard({Key? key, required this.child, required this.title})
      : super(key: key);

  final String title;
  final Widget? child;
  @override
  Widget build(BuildContext context) {
    final double height = MediaQuery.of(context).size.height;
    final double width = MediaQuery.of(context).size.width;
    final TextTheme textThemeData = Theme.of(context).textTheme;
    return Container(
      padding: const EdgeInsets.all(8),
      margin: const EdgeInsets.all(24),
      decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(18),
          color: Theme.of(context).cardColor,
          boxShadow: const [
            BoxShadow(
              color: Colors.black12,
              blurRadius: 12,
              spreadRadius: 2,
            )
          ]),
      height: height * 0.5,
      width: width,
      child: Column(children: [
        Text(
          title,
          style: textThemeData.bodyText2!.copyWith(
            fontSize: width * 0.035,
          ),
        ),
        const Divider(),
        child ?? const SizedBox(),
      ]),
    );
  }
}
